@@ -4,12 +4,12 @@ import json
 
 from trytond.exceptions import UserError
 from trytond.i18n import gettext
-from trytond.model import Model, ModelStorage, ModelView, fields, dualmethod
+from trytond.model import Model, ModelStorage, ModelView, dualmethod, fields
 from trytond.model.exceptions import ValidationError
 from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
-from trytond.wizard import Wizard, StateTransition, StateView, Button
+from trytond.wizard import Button, StateTransition, StateView, Wizard
 
 
 class ShipmentUnassignMixin:
@@ -180,7 +180,6 @@ class ShipmentAssignManualShow(ModelView):
                 ('quantity', '<=', Eval('move_quantity', 0)),
                 ],
             ],
-        depends=['move_quantity'],
         help="The maximum quantity to assign from the place.\n"
         "Leave empty for the full quantity of the move.")
     unit = fields.Many2One('product.uom', "Unit", readonly=True)
@@ -210,7 +209,8 @@ class ShipmentAssignManualShow(ModelView):
 
         location_ids = [loc.id for loc in locations]
         product_ids = [self.move.product.id]
-        stock_date_end = Date.today()
+        with Transaction().set_context(company=self.move.company.id):
+            stock_date_end = Date.today()
         with Transaction().set_context(
                 stock_date_end=stock_date_end,
                 stock_assign=True,
@@ -368,7 +368,6 @@ class ShipmentAssignedMove(ModelView):
                 ('unassigned_quantity', '<=', Eval('move_quantity', 0)),
                 ],
             ],
-        depends=['move_quantity'],
         help="The quantity to unassign")
     assigned_quantity = fields.Float(
         "Assigned Quantity", digits='unit',
@@ -379,7 +378,6 @@ class ShipmentAssignedMove(ModelView):
                 ('assigned_quantity', '<=', Eval('move_quantity', 0)),
                 ],
             ],
-        depends=['move_quantity'],
         help="The quantity left assigned")
     unit = fields.Function(
         fields.Many2One('product.uom', "Unit"), 'on_change_with_unit')
@@ -426,7 +424,6 @@ class ShipmentUnassignManualShow(ModelView):
     moves = fields.One2Many(
         'stock.shipment.assigned.move', None, "Moves",
         domain=[('move.id', 'in', Eval('assigned_moves'))],
-        depends=['assigned_moves'],
         help="The moves to unassign.")
     assigned_moves = fields.Many2Many(
         'stock.move', None, None, "Assigned Moves")
